{% extends 'rewards/base.html' %}


{% block content %}

    <h2 class="pinboard-my-achievements">My achievements</h2>

    <div class="achievements-wrapper">
        {% for obj in object_list %}
        <div class="achievement-item {% cycle '' 'even' %}">
            <span class="goal-target">{{ obj.score }}</span>
            <h3>{{ obj.badge.name }}</h3>
            <h4>{{ obj.name }}</h4>
            <img class="badge" src="{{ obj.badge.image.url }}" />
        </div>
        {% endfor %}
    </div>

{% endblock %}
