{% load url from future %}
<div class="achievement-item">
    <h2>Congratulations!</h2>
    <h3>You have achieved your goal <em>{{ object.name }}</em></h3>
    <h4>{{ object.badge.name|default:'Well Done!' }}</h4>
    <span class="goal-target">{{ object.score }}</span>

    {% if object.badge.image %}<img class="badge" src="{{ object.badge.image.url }}" />{% endif %}

    <a href="{% url 'reward_badges' %}" class="button">See all your Achievements</a>
</div>


